@@ -19,14 +19,12 @@
 import abc
 
 import jsonschema
-import six
 
 from watcher.common import clients
 from watcher.common.loader import loadable
 
 
-@six.add_metaclass(abc.ABCMeta)
-class BaseAction(loadable.Loadable):
+class BaseAction(loadable.Loadable, metaclass=abc.ABCMeta):
     # NOTE(jed): by convention we decided
     # that the attribute "resource_id" is the unique id of
     # the resource to which the Action applies to allow us to use it in the
@@ -131,11 +129,8 @@ class BaseAction(loadable.Loadable):
         raise NotImplementedError()
 
     def validate_parameters(self):
-        try:
-            jsonschema.validate(self.input_parameters, self.schema)
-            return True
-        except jsonschema.ValidationError as e:
-            raise e
+        jsonschema.validate(self.input_parameters, self.schema)
+        return True
 
     @abc.abstractmethod
     def get_description(self):
@@ -143,7 +138,7 @@ class BaseAction(loadable.Loadable):
         raise NotImplementedError()
 
     def check_abort(self):
-        if self.__class__.__name__ is 'Migrate':
+        if self.__class__.__name__ == 'Migrate':
             if self.migration_type == self.LIVE_MIGRATION:
                 return True
             else:
