@@ -15,10 +15,13 @@
 # limitations under the License.
 
 from watcher.decision_engine.strategy.strategies import actuation
+from watcher.decision_engine.strategy.strategies import base
 from watcher.decision_engine.strategy.strategies import basic_consolidation
 from watcher.decision_engine.strategy.strategies import dummy_strategy
 from watcher.decision_engine.strategy.strategies import dummy_with_scorer
 from watcher.decision_engine.strategy.strategies import host_maintenance
+from watcher.decision_engine.strategy.strategies import \
+    node_resource_consolidation
 from watcher.decision_engine.strategy.strategies import noisy_neighbor
 from watcher.decision_engine.strategy.strategies import outlet_temp_control
 from watcher.decision_engine.strategy.strategies import saving_energy
@@ -33,6 +36,7 @@ from watcher.decision_engine.strategy.strategies import zone_migration
 
 
 Actuator = actuation.Actuator
+BaseStrategy = base.BaseStrategy
 BasicConsolidation = basic_consolidation.BasicConsolidation
 OutletTempControl = outlet_temp_control.OutletTempControl
 DummyStrategy = dummy_strategy.DummyStrategy
@@ -43,12 +47,15 @@ VMWorkloadConsolidation = vm_workload_consolidation.VMWorkloadConsolidation
 WorkloadBalance = workload_balance.WorkloadBalance
 WorkloadStabilization = workload_stabilization.WorkloadStabilization
 UniformAirflow = uniform_airflow.UniformAirflow
+NodeResourceConsolidation = (
+    node_resource_consolidation.NodeResourceConsolidation)
 NoisyNeighbor = noisy_neighbor.NoisyNeighbor
 ZoneMigration = zone_migration.ZoneMigration
 HostMaintenance = host_maintenance.HostMaintenance
 
-__all__ = ("Actuator", "BasicConsolidation", "OutletTempControl",
-           "DummyStrategy", "DummyWithScorer", "VMWorkloadConsolidation",
-           "WorkloadBalance", "WorkloadStabilization", "UniformAirflow",
-           "NoisyNeighbor", "SavingEnergy", "StorageCapacityBalance",
-           "ZoneMigration", "HostMaintenance")
+__all__ = ("Actuator", "BaseStrategy", "BasicConsolidation",
+           "OutletTempControl", "DummyStrategy", "DummyWithScorer",
+           "VMWorkloadConsolidation", "WorkloadBalance",
+           "WorkloadStabilization", "UniformAirflow", "NoisyNeighbor",
+           "SavingEnergy", "StorageCapacityBalance", "ZoneMigration",
+           "HostMaintenance", "NodeResourceConsolidation")
