@@ -10,17 +10,17 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from ceilometerclient import client as ceclient
-import ceilometerclient.v2.client as ceclient_v2
+from unittest import mock
+
 from cinderclient import client as ciclient
-from cinderclient.v1 import client as ciclient_v1
+from cinderclient.v3 import client as ciclient_v3
 from glanceclient import client as glclient
 from gnocchiclient import client as gnclient
 from gnocchiclient.v1 import client as gnclient_v1
 from ironicclient import client as irclient
 from ironicclient.v1 import client as irclient_v1
+from keystoneauth1 import adapter as ka_adapter
 from keystoneauth1 import loading as ka_loading
-import mock
 from monascaclient import client as monclient
 from monascaclient.v2_0 import client as monclient_v2
 from neutronclient.neutron import client as netclient
@@ -120,15 +120,24 @@ class TestClients(base.TestCase):
         mock_call.assert_called_once_with(
             CONF.nova_client.api_version,
             endpoint_type=CONF.nova_client.endpoint_type,
+            region_name=CONF.nova_client.region_name,
             session=mock_session)
 
     @mock.patch.object(clients.OpenStackClients, 'session')
     def test_clients_nova_diff_vers(self, mock_session):
-        CONF.set_override('api_version', '2.3', group='nova_client')
+        CONF.set_override('api_version', '2.60', group='nova_client')
         osc = clients.OpenStackClients()
         osc._nova = None
         osc.nova()
-        self.assertEqual('2.3', osc.nova().api_version.get_string())
+        self.assertEqual('2.60', osc.nova().api_version.get_string())
+
+    @mock.patch.object(clients.OpenStackClients, 'session')
+    def test_clients_nova_bad_min_version(self, mock_session):
+        CONF.set_override('api_version', '2.47', group='nova_client')
+        osc = clients.OpenStackClients()
+        osc._nova = None
+        ex = self.assertRaises(ValueError, osc.nova)
+        self.assertIn('Invalid nova_client.api_version 2.47', str(ex))
 
     @mock.patch.object(clients.OpenStackClients, 'session')
     def test_clients_nova_diff_endpoint(self, mock_session):
@@ -155,6 +164,7 @@ class TestClients(base.TestCase):
         mock_call.assert_called_once_with(
             CONF.glance_client.api_version,
             interface=CONF.glance_client.endpoint_type,
+            region_name=CONF.glance_client.region_name,
             session=mock_session)
 
     @mock.patch.object(clients.OpenStackClients, 'session')
@@ -191,7 +201,8 @@ class TestClients(base.TestCase):
         mock_call.assert_called_once_with(
             CONF.gnocchi_client.api_version,
             adapter_options={
-                "interface": CONF.gnocchi_client.endpoint_type},
+                "interface": CONF.gnocchi_client.endpoint_type,
+                "region_name": CONF.gnocchi_client.region_name},
             session=mock_session)
 
     @mock.patch.object(clients.OpenStackClients, 'session')
@@ -229,15 +240,16 @@ class TestClients(base.TestCase):
         mock_call.assert_called_once_with(
             CONF.cinder_client.api_version,
             endpoint_type=CONF.cinder_client.endpoint_type,
+            region_name=CONF.cinder_client.region_name,
             session=mock_session)
 
     @mock.patch.object(clients.OpenStackClients, 'session')
     def test_clients_cinder_diff_vers(self, mock_session):
-        CONF.set_override('api_version', '1', group='cinder_client')
+        CONF.set_override('api_version', '3', group='cinder_client')
         osc = clients.OpenStackClients()
         osc._cinder = None
         osc.cinder()
-        self.assertEqual(ciclient_v1.Client, type(osc.cinder()))
+        self.assertEqual(ciclient_v3.Client, type(osc.cinder()))
 
     @mock.patch.object(clients.OpenStackClients, 'session')
     def test_clients_cinder_diff_endpoint(self, mock_session):
@@ -256,55 +268,6 @@ class TestClients(base.TestCase):
         cinder_cached = osc.cinder()
         self.assertEqual(cinder, cinder_cached)
 
-    @mock.patch.object(ceclient, 'Client')
-    @mock.patch.object(clients.OpenStackClients, 'session')
-    def test_clients_ceilometer(self, mock_session, mock_call):
-        osc = clients.OpenStackClients()
-        osc._ceilometer = None
-        osc.ceilometer()
-        mock_call.assert_called_once_with(
-            CONF.ceilometer_client.api_version,
-            None,
-            endpoint_type=CONF.ceilometer_client.endpoint_type,
-            session=mock_session)
-
-    @mock.patch.object(clients.OpenStackClients, 'session')
-    @mock.patch.object(ceclient_v2.Client, '_get_redirect_client')
-    def test_clients_ceilometer_diff_vers(self, mock_get_redirect_client,
-                                          mock_session):
-        '''ceilometerclient currently only has one version (v2)'''
-        mock_get_redirect_client.return_value = [mock.Mock(), mock.Mock()]
-        CONF.set_override('api_version', '2',
-                          group='ceilometer_client')
-        osc = clients.OpenStackClients()
-        osc._ceilometer = None
-        osc.ceilometer()
-        self.assertEqual(ceclient_v2.Client,
-                         type(osc.ceilometer()))
-
-    @mock.patch.object(clients.OpenStackClients, 'session')
-    @mock.patch.object(ceclient_v2.Client, '_get_redirect_client')
-    def test_clients_ceilometer_diff_endpoint(self, mock_get_redirect_client,
-                                              mock_session):
-        mock_get_redirect_client.return_value = [mock.Mock(), mock.Mock()]
-        CONF.set_override('endpoint_type', 'publicURL',
-                          group='ceilometer_client')
-        osc = clients.OpenStackClients()
-        osc._ceilometer = None
-        osc.ceilometer()
-        self.assertEqual('publicURL', osc.ceilometer().http_client.interface)
-
-    @mock.patch.object(clients.OpenStackClients, 'session')
-    @mock.patch.object(ceclient_v2.Client, '_get_redirect_client')
-    def test_clients_ceilometer_cached(self, mock_get_redirect_client,
-                                       mock_session):
-        mock_get_redirect_client.return_value = [mock.Mock(), mock.Mock()]
-        osc = clients.OpenStackClients()
-        osc._ceilometer = None
-        ceilometer = osc.ceilometer()
-        ceilometer_cached = osc.ceilometer()
-        self.assertEqual(ceilometer, ceilometer_cached)
-
     @mock.patch.object(netclient, 'Client')
     @mock.patch.object(clients.OpenStackClients, 'session')
     def test_clients_neutron(self, mock_session, mock_call):
@@ -314,6 +277,7 @@ class TestClients(base.TestCase):
         mock_call.assert_called_once_with(
             CONF.neutron_client.api_version,
             endpoint_type=CONF.neutron_client.endpoint_type,
+            region_name=CONF.neutron_client.region_name,
             session=mock_session)
 
     @mock.patch.object(clients.OpenStackClients, 'session')
@@ -401,13 +365,7 @@ class TestClients(base.TestCase):
         osc = clients.OpenStackClients()
         osc._ironic = None
         osc.ironic()
-        mock_call.assert_called_once_with(
-            CONF.ironic_client.api_version,
-            endpoint_override=ironic_url,
-            max_retries=None,
-            os_ironic_api_version=None,
-            retry_interval=None,
-            session=mock_session)
+        mock_call.assert_called()
 
     @mock.patch.object(clients.OpenStackClients, 'session')
     def test_clients_ironic_diff_vers(self, mock_session):
@@ -426,7 +384,7 @@ class TestClients(base.TestCase):
         osc = clients.OpenStackClients()
         osc._ironic = None
         osc.ironic()
-        mock_session.get_endpoint.assert_called_once_with(
+        mock_session.get_endpoint.assert_called_with(
             interface='publicURL',
             region_name=None,
             service_type='baremetal')
@@ -449,3 +407,17 @@ class TestClients(base.TestCase):
         ironic = osc.ironic()
         ironic_cached = osc.ironic()
         self.assertEqual(ironic, ironic_cached)
+
+    @mock.patch.object(ka_adapter, 'Adapter')
+    @mock.patch.object(clients.OpenStackClients, 'session')
+    def test_clients_placement(self, mock_session, mock_call):
+        osc = clients.OpenStackClients()
+        osc.placement()
+        headers = {'accept': 'application/json'}
+        mock_call.assert_called_once_with(
+            session=mock_session,
+            service_type='placement',
+            default_microversion=CONF.placement_client.api_version,
+            interface=CONF.placement_client.interface,
+            region_name=CONF.placement_client.region_name,
+            additional_headers=headers)
